@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 2.3;
+our $VERSION = 2.4;
 
 1;
 
@@ -61,7 +61,6 @@ sub insert {
         }
     }
 }
-*start_with = *insert;
 
 sub query {
     my $this = shift;
@@ -98,10 +97,6 @@ Math::Business::SMA - Technical Analysis: Simple Moving Average
       print "value: n/a.\n";
   }
 
-To avoid recalculating huge lists when you add a few new values on the end;
-
-  $avg->start_with( $the_last_calculated_value );
-
 For short, you can skip the set_days() by suppling the setting to new():
 
   my $longer_avg = new Math::Business::SMA(10);
@@ -116,6 +111,9 @@ please let me know.
 I normally hang out on #perl on freenode, so you can try to get immediate
 gratification there if you like.  L<irc://irc.freenode.net/perl>
 
+There is also a mailing list with very light traffic that you might want to
+join: L<http://groups.google.com/group/stockmonkey/>.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
